"""
    NVIDIA NeMo LLM service

    # Introduction NVIDIA NeMo LLM service provides a simple and powerful REST API to interact with large language models. This API reference provides information on available endpoints and how to interact with it.  Please **[submit NVBug](https://nvbugswb.nvidia.com/NvBugs5/SWBug.aspx?bugid=3682160&cmtNo=)** (by cloning and submitting) if discovered any issues. Copyright (c) 2022 NVIDIA CORPORATION & AFFILIATES. All rights reserved. Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the \"Software\"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import nemollm
from nemollm.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_customization(self):
        """Test case for create_customization

        Create a customization for a base model trained on a custom dataset.  # noqa: E501
        """
        pass

    def test_delete_customization(self):
        """Test case for delete_customization

        Delete the custom model  # noqa: E501
        """
        pass

    def test_delete_file(self):
        """Test case for delete_file

        Delete file  # noqa: E501
        """
        pass

    def test_fetch_model_file_for_customization(self):
        """Test case for fetch_model_file_for_customization

        Fetch NEMO file with trained prompt tokens  # noqa: E501
        """
        pass

    def test_generate_completion(self):
        """Test case for generate_completion

        Create text completion.  # noqa: E501
        """
        pass

    def test_generate_customization_completion(self):
        """Test case for generate_customization_completion

        Create text completion using customization for a model  # noqa: E501
        """
        pass

    def test_get_customization(self):
        """Test case for get_customization

        Get information and status about the custom model  # noqa: E501
        """
        pass

    def test_get_file(self):
        """Test case for get_file

        Get file  # noqa: E501
        """
        pass

    def test_list_customizations_for_model(self):
        """Test case for list_customizations_for_model

        List downstream customizations for the model  # noqa: E501
        """
        pass

    def test_list_files(self):
        """Test case for list_files

        List all files  # noqa: E501
        """
        pass

    def test_list_models(self):
        """Test case for list_models

        List available models  # noqa: E501
        """
        pass

    def test_upload_file(self):
        """Test case for upload_file

        File upload  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
